AurPackageVoteState

Enum AurPackageVoteState 

pub enum AurPackageVoteState {
    Voted,
    NotVoted,
}
What: Live vote-state of the current user for one AUR package base.

Details:

  • Voted means the account currently has an active vote.
  • NotVoted means no vote exists for the package base.

Variants



Voted

User has voted for this package base.



NotVoted

User has not voted for this package base.