take_network_error

Function take_network_error 

pub fn take_network_error() -> bool
What: Check and clear the network error flag.

Inputs: None

Output: true if a network error occurred since the last check, false otherwise.

Details:

  • Atomically loads and clears the flag.
  • Used by the UI to show a toast when news fetch had network issues.