NewsFeedContext

Struct NewsFeedContext 

pub struct NewsFeedContext<'a, HS, HV, HC>
where HS: BuildHasher + Send + Sync + 'static, HV: BuildHasher + Send + Sync + 'static, HC: BuildHasher + Send + Sync + 'static,
{
Show 13 fields pub force_emit_all: bool, pub updates_list_path: Option<PathBuf>, pub limit: usize, pub include_arch_news: bool, pub include_advisories: bool, pub include_pkg_updates: bool, pub include_aur_comments: bool, pub installed_filter: Option<&'a HashSet<String, HS>>, pub installed_only: bool, pub sort_mode: NewsSortMode, pub seen_pkg_versions: &'a mut HashMap<String, String, HV>, pub seen_aur_comments: &'a mut HashMap<String, String, HC>, pub max_age_days: Option<u32>,
}
What: Input context for fetching a combined news feed.

Inputs:

  • limit: Maximum number of items per source.
  • include_*: Source toggles.
  • installed_filter: Optional installed-package set for scoping.
  • installed_only: Whether to restrict advisories to installed packages.
  • sort_mode: Sort order.
  • seen_pkg_versions: Last-seen map for package updates.
  • seen_aur_comments: Last-seen map for AUR comments.
  • max_age_days: Optional maximum age in days for filtering items (enables early filtering).

Output:

  • Mutable references updated in place alongside returned feed items.

Details:

  • Hashers are generic to remain compatible with caller-supplied maps.
  • max_age_days enables early date filtering during fetch to improve performance.

Fields

force_emit_all: bool

Emit all sources even on first run (bypasses baseline gating).

updates_list_path: Option<PathBuf>

Optional path to available_updates.txt for filtering noisy first-run emissions.

limit: usize

Maximum number of items per source.

include_arch_news: bool

Whether to include Arch news RSS posts.

include_advisories: bool

Whether to include security advisories.

include_pkg_updates: bool

Whether to include installed package updates.

include_aur_comments: bool

Whether to include installed AUR comments.

installed_filter: Option<&'a HashSet<String, HS>>

Optional installed-package filter set.

installed_only: bool

Whether to restrict advisories to installed packages.

sort_mode: NewsSortMode

Sort mode for the resulting feed.

seen_pkg_versions: &'a mut HashMap<String, String, HV>

Last-seen versions map (updated in place).

seen_aur_comments: &'a mut HashMap<String, String, HC>

Last-seen AUR comments map (updated in place).

max_age_days: Option<u32>

Optional maximum age in days for early date filtering during fetch.